Glaciers are formed by snow that falls and compacts into solid ice. The ice can flow downhill and where it reaches warmer altitudes, or reaches the sea, the ice can melt or break off in chunks. Large continuously glaciated areas are known as ice sheets. Currently, there are two ice sheets found on Greenland and Antarctica.

Observations and measurements of glaciers and ice sheets shown that they have been losing mass in the past few decades.

## What the IPCC says

A1.5 Human influence is very likely the main driver of the global retreat of glaciers since the 1990s and the decrease in Arctic sea ice area between 1979-1988 and 2010-2019 (decreases of about 40% in September and about 10% in March). There has been no significant trend in Antarctic sea ice area from 1979 to 2020 due to regionally opposing trends and large internal variability. Human influence very likely contributed to the decrease in Northern Hemisphere spring snow cover since 1950. It is very likely that human influence has contributed to the observed surface melting of the Greenland Ice Sheet over the past two decades, but there is only limited evidence, with medium agreement, of human influence on the Antarctic Ice Sheet mass loss.